# Generated by roxygen2: do not edit by hand

export(MOBResult)
export(MultiOmicsBridgeAnalysis)
export(biomarkerDiscovery)
export(biomarkers)
export(diagnosticClassifier)
export(featureLoadings)
export(generateReport)
export(integrationScores)
export(jointDimReduction)
export(loadHostData)
export(loadMicrobiomeData)
export(matchSamples)
export(performance)
export(plotBiomarkerNetwork)
export(plotClassifierComparison)
export(plotIntegration)
export(plotSankey)
exportClasses(MOBResult)
exportMethods(biomarkers)
exportMethods(featureLoadings)
exportMethods(integrationScores)
exportMethods(performance)
exportMethods(show)
importClassesFrom(MultiAssayExperiment,MultiAssayExperiment)
importFrom(BiocParallel,SerialParam)
importFrom(MultiAssayExperiment,MultiAssayExperiment)
importFrom(MultiAssayExperiment,colData)
importFrom(MultiAssayExperiment,experiments)
importFrom(S4Vectors,DataFrame)
importFrom(SummarizedExperiment,SummarizedExperiment)
importFrom(SummarizedExperiment,assay)
importFrom(SummarizedExperiment,assayNames)
importFrom(SummarizedExperiment,colData)
importFrom(edgeR,DGEList)
importFrom(edgeR,normLibSizes)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_flip)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_abline)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_errorbar)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_rect)
importFrom(ggplot2,geom_segment)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,position_dodge)
importFrom(ggplot2,scale_color_brewer)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_colour_manual)
importFrom(ggplot2,scale_fill_gradient2)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_size_identity)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,theme_void)
importFrom(limma,voom)
importFrom(methods,is)
importFrom(methods,new)
importFrom(methods,show)
importFrom(mixOmics,block.splsda)
importFrom(pROC,auc)
importFrom(pROC,roc)
importFrom(ranger,ranger)
importFrom(rlang,.data)
importFrom(stats,dist)
importFrom(stats,hclust)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,var)
importFrom(utils,head)
