% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AllClasses.R
\name{show,MOBResult-method}
\alias{show,MOBResult-method}
\title{Show method for MOBResult}
\usage{
\S4method{show}{MOBResult}(object)
}
\arguments{
\item{object}{A \code{MOBResult} object.}
}
\value{
Invisibly returns \code{object}.
}
\description{
Prints a compact summary of a \code{MOBResult} object,
  including the top biomarkers, integration method, and classifier
  AUC-ROC values.
}
