% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AllClasses.R
\name{performance}
\alias{performance}
\alias{performance,MOBResult-method}
\title{Accessor for classifier performance in a MOBResult}
\usage{
performance(x, ...)

\S4method{performance}{MOBResult}(x, ...)
}
\arguments{
\item{x}{A \code{MOBResult} object.}

\item{...}{Additional arguments (not used).}
}
\value{
A named \code{list} with elements \code{host_only},
  \code{microbiome_only}, and \code{joint}, each containing
  \code{mean_auc}, \code{sd_auc}, and \code{fold_auc}.
}
\description{
Returns the cross-validated classifier performance metrics
  from a \code{MOBResult} object.
}
\examples{
library(S4Vectors)
cr <- list(host_only = list(mean_auc = 0.85),
           microbiome_only = list(mean_auc = 0.78),
           joint = list(mean_auc = 0.92))
obj <- MOBResult(matrix(rnorm(20), 10, 2), list(),
                 DataFrame(), cr)
performance(obj)

}
